Publications
************

Further conceptual and technical information on DataLad, and applications built on DataLad,
are available from the publications listed below.

The best of both worlds: Using semantic web with JSOB-LD. An example with NIDM Results & DataLad [poster]
   - Camille Maumet, Satrajit Ghosh, Yaroslav O. Halchenko, Dorota Jarecka, Nolan Nichols, Jean-Baptist POline, Michael Hanke

One thing to bind them all: A complete raw data structure for auto-generation of BIDS datasets [poster]
   - Benjamin Poldrack, Kyle Meyer, Yaroslav O. Halchenko, Michael Hanke

Fantastic containers and how to tame them [poster]
   - Yaroslav O. Halchenko, Kyle Meyer, Matt Travers, Dorota Jarecka, Satrajit Ghosh, Jakub Kaczmarzyk, Michael Hanke

YODA: YODA's Organigram on Data Analysis [poster]
   - An outline of a simple approach to structuring and conducting data analyses that aims to
     tightly connect all their essential ingredients: data, code, and computational environments
     in a transparent, modular, accountable, and practical way.
   - Michael Hanke, Kyle A. Meyer, Matteo Visconti di Oleggio Castello, Benjamin Poldrack, Yaroslav O. Halchenko
   - F1000Research 2018, 7:1965 (https://doi.org/10.7490/f1000research.1116363.1)

Go FAIR with DataLad [talk]
   - On DataLad's capabilities to create and maintain Findable, Accessible, Interoperable, and Re-Usable (FAIR)
     resources.
   - Michael Hanke, Yaroslav O. Halchenko
   - Bernstein Conference 2018 workshop: Practical approaches to research data management and reproducibility
     (`slides <https://rawgit.com/psychoinformatics-de/talk-datalad-gofair/master/index.html>`__)
   - OpenNeuro kick-off meeting, 2018, Stanford (`slide sources <https://github.com/datalad/talk-openneuro-2018>`__)
